#
# spec file for package icu
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           icu
%define lname	libicu52_1
Version:        52.1
Release:        18.1
%define aversion 52_1
Summary:        International Components for Unicode
License:        MIT
Group:          Development/Libraries/C and C++
Url:            http://icu-project.org/

#DL-URL:	http://download.icu-project.org/files/icu4c/%version/icu4c-%aversion-src.tgz
Source:         icu4c-%aversion-src.tar.xz
Source2:        icu4c-%aversion-docs.tar.xz
Source3:        sanitize_docs.sh
Patch1:         icu-rpmlint.diff
Patch2:         icu-remove-datetime.patch
Patch3:         icu-versioning.diff
Patch4:         icu-fix-install-mode-files.diff
Patch5:         icu-fix-tests-depending-on-date.patch
# PATCH-FIX-UPSTREAM bnc#917129 ticket:11371 icu-CVE-2014-9654.patch pwieczorkiewicz@suse.com -- Improved checking of regular expression pattern size limits.
Patch6:         icu-CVE-2014-9654.patch
# PATCH-FIX-UPSTREAM bnc#929629 ticket:11451 icu-CVE-2014-8146.patch fezhang@suse.com -- Add overflow fix.
Patch7:         icu-CVE-2014-8146.patch
# PATCH-FIX-UPSTREAM bnc#929629 ticket:11451 icu-CVE-2014-8147.patch fezhang@suse.com -- Fix potential overflow issue.
Patch8:         icu-CVE-2014-8147.patch
# PATCH-FIX-UPSTREAM icu-CVE-2016-6293-2017-7867-2017-7868-2017-14952-2017-15422-2017-17484.patch
# bnc#990636 CVE-2016-6293 bnc#1034674 CVE-2017-7868 bnc#1034678 CVE-2017-7867 bnc#1067203 CVE-2017-14952 bnc#1072193 CVE-2017-17484 bnc#1077999 CVE-2017-15422 
# qzhao@suse.com -- Porting upstream security fixes.
Patch9:         icu-CVE-2016-6293-2017-7867-2017-7868-2017-14952-2017-15422-2017-17484.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ICU is a set of C and C++ libraries that provides robust and
full-featured Unicode and locale support. The library provides calendar
support, conversions for many character sets, language sensitive
collation, date and time formatting, support for many locales, message
catalogs and resources, message formatting, normalization, number and
currency formatting, time zone support, transliteration, and word,
line, and sentence breaking, etc.

This subpackage contains the runtime programs for interacting with ICU.

%package -n %lname
Summary:        International Components for Unicode
Group:          System/Libraries
%ifarch ppc64
# bug437293
Obsoletes:      libicu-64bit
%endif
Requires:       timezone
Obsoletes:      icu-i18ndata
# Following O/P added in timeframe for 12.2
Provides:       libicu = %version-%release
Obsoletes:      libicu < %version-%release
Requires:       libicu%aversion-data

%description -n %lname
ICU is a set of C and C++ libraries that provides robust and
full-featured Unicode support. This package contains the runtime
libraries for ICU which include precompiled locale data.

%package -n libicu%aversion-data
Summary:        International Components for Unicode
Group:          System/Libraries

%description -n libicu%aversion-data
ICU is a set of C and C++ libraries that provides robust and
full-featured Unicode support. This package contains the runtime
libraries for ICU which include precompiled locale data.

This subpackage contains the precompiled ICU databases that contain
most of the locale-specific information.

%package -n libicu-devel
Summary:        International Components for Unicode (development files)
Group:          Development/Libraries/C and C++
%ifarch ppc64
# bug437293
Obsoletes:      libicu-devel-64bit
%endif
Requires:       %lname = %version

%description -n libicu-devel
ICU is a C++ and C library that provides robust and full-featured
Unicode support. This package contains the development files for ICU.

%package -n libicu-doc
Summary:        International Components for Unicode  (html documentation)
Group:          Development/Libraries/C and C++

%description -n libicu-doc
ICU is a C++ and C library that provides robust and full-featured
Unicode support. This package contains the html documentation.

%package data
Summary:        International Components for Unicode (Sources for the Data in ICU)
Group:          System/Libraries
Requires:       %lname >= %version

%description data
ICU is a C++ and C library that provides robust and full-featured
Unicode support. This package contains the source files for the data
found in the "icu" package.

This data describes the Unicode data (normative and informative) and
also all the table-based converters provided in the ICU distribution.

This package contains uncompiled source data.

%prep
%setup -qn icu -a2
%patch -P 1 -P 2 -P 3 -P 4 -p1 -P 5 -p1 -P 6 -P 7 -P 8
%patch9 -p1

%build
cd source
export CXXFLAGS="%optflags -DICU_DATA_DIR=\\\"/usr/share/icu/%version/\\\""
export CFLAGS="$CXXFLAGS"
%configure --disable-static --enable-shared --disable-samples \
	--with-data-packaging=archive
make %{?_smp_mflags}

%install
b="%buildroot"
mkdir -p "$b/%_docdir/%name"
cp -a html "$b/%_docdir/%name/"
cp -a license.html readme.html "$b/%_docdir/%name/"

find . -name CVS -type d -exec rm -Rf "{}" "+"
cd source

make install DESTDIR="$b";

#
# ICU's "pkgdata" utility is really fragile, so icu-versioning.diff
# does as few as possible, but that means we need some additional
# cleanup in the spec file now.
#
pushd "$b/%_libdir/"
for i in *.so.[0-9]*; do
	echo "Looking at $i"
	if [ "${i##*.so.}" != "%version" ]; then
		rm -fv "$i"
		continue
	fi
	# Because U_ICU_VERSION_SHORT is "51_2" and not "51.2",
	# create some symlinks.
	ln -s "$i" "${i%%%version}%aversion"
done
popd

# /usr/lib/rpm/elfdeps requires +x bit and not all had it at one point
chmod a+rx "$b/%_libdir"/lib*.so.*

# install uncompiled source data:
mkdir -p "$b/%_datadir/icu/%version/unidata"
install -m 644 data/unidata/*.txt "$b/%_datadir/icu/%version/unidata"
ln -s unidata/UnicodeData.txt "$b/%_datadir/icu/%version/"

rm "$b/%_datadir/icu/%version/license.html"
rm "$b/%_datadir/icu/%version/install-sh"

%fdupes %buildroot/%_prefix

%check
#ln source/data/in/icudt51l.dat source/data/in/icudt%{version}l.dat
cd source
%if !0%{?qemu_user_space_build:1}
# Checks disabled in qemu because of races happening when we emulate
# multi-threaded programs, and some check tests atomic instructions in
# multi-threaded icu invocations
ICU_DATA="%buildroot/%_datadir/icu/%version" make check VERBOSE=1
%endif

# This should be run by whatever owns /usr/lib64/icu -
# the (main) package in this case
%post
if test -d "%_libdir/icu"; then
	current=$(cd "%_libdir/icu/"; find [0-9]* -maxdepth 1 -type d -printf '%f\n' |
		sort -V | tail -n1);
	if test -n "$current"; then
		rm -f "%_libdir/icu/current";
		ln -sv "$current" "%_libdir/icu/current";
	fi;
fi;

%postun
if test -d "%_libdir/icu"; then
	current=$(cd "%_libdir/icu/"; find [0-9]* -maxdepth 1 -type d -printf '%f\n' |
		sort -V | tail -n1);
	if test -n "$current"; then
		rm -f "%_libdir/icu/current";
		ln -sv "$current" "%_libdir/icu/current";
	fi;
fi;

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%dir %_libdir/icu
%dir %_libdir/icu/%version
%_libdir/icu/current
%_bindir/derb
%_bindir/gen*
%_bindir/icuinfo
%_bindir/makeconv
%_bindir/pkgdata
%_bindir/uconv
%_sbindir/*
%_mandir/man*/*
%dir %_docdir/%name/
%_docdir/%name/license.html
%_docdir/%name/readme.html

%files -n %lname
%defattr(-, root, root)
%_libdir/libicu*.so.*

%files -n libicu%aversion-data
%defattr(-,root,root)
%dir %_datadir/icu
%dir %_datadir/icu/%version
%ifarch %sparc mips hppa ppc ppc64 s390 s390x
%_datadir/icu/%version/icudt52b.dat
%else
%_datadir/icu/%version/icudt52l.dat
%endif

%files -n libicu-devel
%defattr(-, root, root)
%_libdir/libicu*.so
%_includedir/unicode/
%_includedir/layout/
%dir %_libdir/icu/
%dir %_libdir/icu/%version/
%_libdir/icu/%version/Makefile.inc
%_libdir/icu/%version/pkgdata.inc
%_libdir/icu/Makefile.inc
%_libdir/icu/pkgdata.inc
%_libdir/pkgconfig/icu-*.pc
%_bindir/icu-config
%dir %_datadir/icu/
%dir %_datadir/icu/%version/
%_datadir/icu/%version/mkinstalldirs
%_datadir/icu/%version/config/

%files -n libicu-doc
%defattr(-,root,root)
%dir %_docdir/%name/
%_docdir/%name/html/

%files data
%defattr(-, root, root)
%dir %_datadir/icu/
%dir %_datadir/icu/%version/
%_datadir/icu/%version/unidata/
%_datadir/icu/%version/UnicodeData.txt

%changelog
* Wed Apr 25 2018 qzhao@suse.com
- Add
  icu-CVE-2016-6293-2017-7867-2017-7868-2017-14952-2017-15422-2017-17484.patch
  Porting upstream security fixes(bnc#990636 CVE-2016-6293
  bnc#1034674 CVE-2017-7868 bnc#1034678 CVE-2017-7867 bnc#1067203
  CVE-2017-14952 bnc#1072193 CVE-2017-17484 bnc#1077999
  CVE-2017-15422).
* Thu Apr  7 2016 fezhang@suse.com
- Add icu-CVE-2014-8146.patch:
  Add overflow fix.
  (bsc#929629, CVE-2014-8146)
- Add icu-CVE-2014-8147.patch:
  Fix potential overflow issue.
  (bsc#929629, CVE-2014-8147)
* Fri Feb 27 2015 pwieczorkiewicz@suse.com
- Add icu-CVE-2014-9654.patch:
  Improved checking of regular expression pattern size limits.
  (bnc#917129,CVE-2014-9654)
* Wed Aug 13 2014 behlert@suse.de
- libicu%%aversion-data may not be noarch, as it has arch-specific
  content wrt.  endianess [bnc#889837]
* Mon Jun 16 2014 coolo@suse.com
- add icu-fix-tests-depending-on-date.patch to fix build
  see http://sourceforge.net/p/icu/mailman/message/32443311/
* Fri Mar  7 2014 ro@suse.de
- s390 is big endian as well
* Tue Nov 12 2013 jengelh@inai.de
- Update to new upstream release 52.1
  * Unicode 6.3: New bidi control codes, new Bidi_Class property
  values, two new bidi "bracket" properties; for other property
  value changes see the UAX #44 summary.
  * CLDR 24: Improved coverage for top 70+ languages, fractional
  plural rules and forms, many new measurement units, major
  simplification of collation rule syntax, preliminary version of
  European Ordering Rules, new relative fields.
  * New API for converting between Windows time zone ID and IANA tz
  database ID.
  * Implement support for plurals that depend on displayed fractional
  values
* Mon Jul 29 2013 dvaleev@suse.com
- make filelist depend on architecture
  icudt51b.dat - on BigEndian platforms
  icudt51l.dat - on LittleEndian
* Tue Jul 23 2013 jengelh@inai.de
- Add missing symlinks and update description in icu-versioning.diff
* Sun Jul 14 2013 jengelh@inai.de
- Change icu-versioning.diff: Resolve libqt4 emitting a warning
  that it cannot dlopen libicui18n.so
- Build I18N data as a plain file rather than as an arch-dependent
  huge shared library
- Add icu-fix-install-mode-files.diff
* Sat Jun 15 2013 jengelh@inai.de
- Add icu-versioning.diff:
  Treat each minor release as a new SONAME (bnc#824262)
* Wed Jun  5 2013 jengelh@inai.de
- Update to new upstream release 51.2
  * Common Locale Data Repository (CLDR) 23.1
  * Time zone database version 2013c
  * Security fixes for font layout and glyph table errors. NOTE:
  Applications must implement
  LEFontInstance::getFontTable(LETag, size_t &length) in their
  LEFontInstance subclasses, so that ICU can properly bounds-check
  font tables.
* Mon May  6 2013 jengelh@inai.de
- Update RPM group, description, URL
* Tue Mar 26 2013 jengelh@inai.de
- Update to new upstream release 51
  * Collation tailorings put native script first;
  non-Gregorian calendar formats are more consistent;
  * Date format/parse now supports CLDR short weekday names
  * Support DisplayContext for date formatting, locale display names
  * Support new timezone pattern characters in LDML spec
  * Support for “dangi” Korean luni-solar calendar
  * Add CompactDecimalFormat and TerritoryContainment APIs
  * ICU50 regression fix: Affixes set with e.g.
  DecimalFormat::setPositivePrefix were ignored for parse
  * ICU50 regression fix: UNUM_PARSE_INT_ONLY no longer handled
  grouping separator
- Recompress to xz to save space
* Fri Jan 25 2013 cfarrell@suse.com
- license update: X11
  official spdx.org license list now contains an entry for X11
* Sat Jan 19 2013 idonmez@suse.com
- Update to version 50.1.2
  * Fix an ABI regression introduced in 50.1, icu bug#9826
* Wed Nov 14 2012 jengelh@inai.de
- Update to new upstream release 50
  * Unicode 6.2: Turkish Lira Sign, improved word & line segmentation
  (BreakIterator) for symbols
  * CLDR 22.1: Data coverage & quality improved across all major
  languages; new short width type for weekday names; new zhuyin
  (Bopomofo) collation for Chinese; improved data for
  CompactDecimalFormat & RBNF
  * Time zone data: 2012h
  * Ordinal-number support in MessageFormat & PluralRules
  * Deprecate setLocale(locale) in PluralFormat
  * Dictionary-based break iterators (word segmentation)
* Wed Jul 11 2012 jengelh@inai.de
- Remove SuSEconfig.icu; only run the link updater on icu updates
  (FATE#313539)
* Wed Jun 13 2012 cfarrell@suse.com
- license update: SUSE-XFree86-1.0
  The license (as stated in the license.html page) is not upstream at
  http://www.spdx.org/licenses yet - thus, use this version (with SUSE-
  proprietary prefix until the license goes upstream)
* Tue Apr 10 2012 cfarrell@suse.com
- license update: MIT and SUSE-Public-Domain
  This is _not_ IBM Public License code.
* Tue Apr  3 2012 jengelh@medozas.de
- Update to new upstream release 49.1:
  * Unicode 6.1: New scripts & blocks; changes to grapheme break &
  line break property values; some characters change from symbol to
  Po or No; etc.
  * CLDR 21.0.1: Changes in segmentation data to match Unicode 6.1;
  new structures for support of Chinese calendar, for
  context-dependent capitalization, for gender of lists of people,
  for ordinal categories, and for multiple number systems per
  locale; deprecation of "commonlyUsed" element in timezone names;
  removal of "whole-locale" aliases; major cleanups of timezone
  names, delimiter data, abbreviated number data.
  * Support for ISO 4217 numeric currency code
  * See http://site.icu-project.org/download/49 for more
* Sat Feb 25 2012 jengelh@medozas.de
- Use shlib policy for icu package
- Use proper data directory in CXXFLAGS
* Wed Jan 18 2012 vuntz@opensuse.org
- Update to version 4.8.1.1:
  + Time zone database version 2011k
  + Several bug fixes.
- Changes from version 4.8.1:
  + Common Locale Data Repository (CLDR) 2.0.1
  + Time zone database version 2011h
  + Several bug fixes.
- Changes from version 4.8.0:
  + Common Changes:
  - CLDR 2.0: The CLDR 2.0 release contains numerous improvements
    and bug fixes approved by the CLDR committee, including much
    additional data for many languages.
  - Explicit parent locale support in data imported from CLDR
  - MessageFormat and related classes (choice/plural/select) have
    been reimplemented, with several improvements and some
    incompatible changes.
  - Extended PluralFormat pattern syntax supports explicit-value
    forms and offsets.
  - Utility APIs in PluralRules (get some/all/unique keyword
    values)
  - Time zone API to return a list of available canonical system
    time zone IDs
  - Time zone API to return a region
  - Collation: Full implementation & public API for script
    reordering
  - Dictionary-type trie
  - GB18030-2005 update
  + ICU4C Specific Changes:
  - Alphabetic Index support ported from ICU4J
  - X11 Compound Text encoding support ported from ICU4J
  - Appendable interface
- Add unzip BuildRequires to handle .zip source file.
- Change the way we unpack the docs zip file: we need to create the
  html subdirectory first, so we don't unpack via %%setup but with
  an explicit call to unzip.
* Sat Dec 24 2011 vuntz@opensuse.org
- Remove call to suse_update_config, and stop removing
  config.cache.
* Thu Dec 22 2011 vuntz@opensuse.org
- Add automake BuildRequires that was implicit before, to fix
  build.
* Wed Oct 12 2011 vuntz@opensuse.org
- Drop pkgdata.diff: everything leads me to think this is not
  needed anymore. Debian doesn't ship this patch with its 4.4
  version of ICU. This patch was just a workaround in the first
  place anyway.
* Tue Oct 11 2011 dmueller@suse.de
- Disable "make check" when run under qemu.
* Tue Aug  2 2011 idonmez@novell.com
- Enable strict-aliasing again since the code seems to be fixed.
- Enable make check inside %%check.
- Cleanup the spec file with spec-cleaner.
* Thu May  5 2011 vuntz@opensuse.org
- Update to version 4.6.1:
  + Common Locale Data Repository (CLDR) 1.9.1
  + Update timezone data support to Olson 2011c
  + Fix: UCOL_RUNTIME_VERSION should be updated for 4.6
  + Fix: Collation Reordering Use Of USCRIPT_UNKNOWN
  + Fix: Can't find Hangul with search coll (usearch doesn't handle
    CE iter behavior)
  + Fix: ULocale#toLanguageTag() should not supply "und" as
    language when the locale has only private use
  + Fix: USpoof uses NFKD, should be NFD
  + ICU4C-specific bug fixes, including:
  - ICU misparses numbers in scientific notation
  - detect out of memory issue for Hashtable in low memory
    situations
- Changes from version 4.6.0:
  + Unicode 6.0:
  - Supports final version of Unicode 6.0
  - New UCA data for collation/sorting, with refinements from
    CLDR; this data is revamped for more effective use of
    collation weights, and noncharacters are now handled
  - Support for 2,088 new characters, including the new emoji and
    Indian Rupee sign
  - Fully updated properties
  + CLDR 1.9:
  - Supports final version of CLDR 1.9
  - The CLDR release contains numerous improvements and bug fixes
    approved by the CLDR committee, mainly in the areas of
    collation sequences, transliteration, and available date
    formats.
  + Support for UTS #46 Unicode IDNA Compatibility Processing.
  + Alternate number symbols based on numbering system.
  + Compact collation tailoring syntax for reduced memory and disk
    footprint.
  + New collation [import] rule for reduced footprint and improved
    maintenance.
  + Fast string BiDi direction detection.
  + ICU4C-specific changes:
  - ICU 4.6 requires compiler RTTI to be turned on. Please see
    the ICU4C readme for more details.
  - pkg-config files for a standard way of linking against ICU.
  - Promotion to @draft (from @internal) for most regex functions
    that provide access via UText.
  - Regex support for a "find progress" callback.
  - Enhance regex APIs to support full 64-bit offsets and
    indices.
  - New regex API to set match and start position independently.
- Update icu-remove-datetime.patch to apply without fuzz.
- Rebase icu44-rpmlint.diff.
- Add pkg-config BuildRequires to automatically get
  pkgconfig()-style Provides.
* Fri Jan 14 2011 vuntz@opensuse.org
- Update to version 4.4.2:
  + Common Changes:
  - Update LMBCS mapping table
  - Time zone data 2010l
  + ICU4C Specific Changes:
  - Fix: Difference between Java and C implementation with
    exponent characters
  - Fix: u_fflush (and thus u_fclose) not flushing stateful
    converter
  - Fix: unum_parseInt64 is not giving proper error
  - Fix: Missing header files in Windows build
* Thu Jul  8 2010 jengelh@medozas.de
- Update to version 4.4.1
  + Common Changes
  - Common Locale Data Repository (CLDR) 1.8.1
  - Enabled non-Gregorian calendars in DateIntervalFormat
- Changes from version 4.4:
  + Common Changes
  - Unicode 5.2 support.
  - CLDR 1.8 data - over 22%% more data, with many new locales.
  - Normalizer2 - for fast, flexible normalization, paving the
    way for UTS #46 support of international domain names.
  - Optimized resource bundle format to reduce the ICU resource
    bundle installation footprint.
  - Hebrew calendar month numbering improvement.
  - Finer granular ICU locale resource data packaging.
  - SelectFormat - for selecting a translation by a keyword among
    multiple alternatives when formatting messages.
  - Flexible hour pattern handling in DateFormatPatternGenerator.
  - Updated LMBCS converter implementation.
  - EBCDIC converter enhancement for supporting various SI/SO
    codes used by non-IBM mainframes.
  - 64bit time zone transition data support.
  + ICU4C Specific Changes
  - Regular Expressions support UText - allowing regular
    expressions to work on large or discontiguous text
    (Technology Preview).
  - DecimalFormat support for big decimal numbers.
  - ICU Plug-ins - for packaging a specific ICU servce as plug-in
    and calling different versions of plug-ins in a same
    environment (Technology Preview).
  - C++ public smart pointers.
  - Java modified UTF-8 support.
  - Improved UnicodeString substring operations.
  - New usearch options to control matching of collation elements
- Use %%_smp_mflags
- Add icu44-rpmlint.diff to fix some build errors.
- Add pkgdata.diff to help build on some architecture, see
  http://bugs.icu-project.org/trac/ticket/6969#comment:19.
* Tue Apr 20 2010 crrodriguez@opensuse.org
- In JeOS, libicu is installed by default but it should
  require timezone package to fullfill all dependencies.
* Tue May 26 2009 vuntz@novell.com
- Drop icu4c-3_6-src-setBreakType-public.diff: it's not needed
  anymore for OOo.
* Sat May 23 2009 vuntz@novell.com
- Update to 4.2:
  + Locale Data: ICU uses and supports data from Common Locale Data
    Repository (CLDR) 1.7 , which includes data for 146 languages,
    159 territories, 468 locales- 21%% more locale data than the
    previous release.
  + Number system support and the number keyword.
  + Number system override in DateFormat.
  + Numerics used by Hebrew Calendar date in Hebrew locale.
  + BCP47 (language tag) / Locale transformation.
  + BCP47 mapping of LDML keywords.
  + Encoding selector: Return a list of charsets that can handle
    the input text.
  + Simple duration: Implementation of CLDR duration format.
  + Available/Preferred keywords for a locale (Calendar, Collation,
    and Currency).
  + StringPrep standard profiles: RFC3491 NAMEPREP, RFC3530 NFS4,
    RFC3722 iSCSI, RFC3920 NodePrep/ResourcePrep, RFC4011 MIB,
    RFC4013 SASLprep, RFC4505 trace and RFC4518 LDAPprep.
  + Miscellaneous Arabic shaping enhancements.
  + UTF-8 friendly internal data structure for Unicode data lookup.
  + API to get CLDR version used by ICU.
  + ISCII charset converter updates (added Gurumukhi, other
    updates).
  + Performance improvements in Time Zone Name format/parse, and in
    DateIntervalFormat construction.
- Remove AutoReqProv: it's default now.
- Drop icu-gcc44.patch: fixed upstream.
- Do not package packaging doc in libicu-doc.
* Fri Mar 27 2009 vuntz@novell.com
- Add icu-remove-datetime.patch to be more build-compare friendly.
* Mon Mar  2 2009 crrodriguez@suse.de
- fix build with GCC 4.4
- remove static libraries
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Sat Sep 13 2008 vuntz@novell.com
- Merge with openSUSE:Factory. Redo the patch tags that were done
  by jpr@novell.com
* Fri Sep  5 2008 maw@suse.de
- Update to version 4.0:
  (All of the bug numbers listed are against
  http://bugs.icu-project.org/trac)
  + Update to Unicode 5.1 (#5696)
  + Locale Data: ICU uses and supports data from Common Locale Data
    Repository (CLDR) 1.6, which includes many improvements in
    quality and quantity of data
  + Add/removeLikelySubtags (#6124)
  + Charset converter file size improvement (#5987)
  + Date Interval Formatting (#6157) Note: Calendar type supported
    by this feature is Gregorian only in this release
  + Improved Plural support
  + Additional calendars: Chinese (#4081) and Coptic/Ethiopic
    (#4571)
  + Security fixes for CVE-2007-4770, CVE-2007-4771, and
    CVE-2008-1036.
- Drop libicu-regex.patch, which has been upstreamed.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Feb 13 2008 maw@suse.de
- Update to version 3.8:
  + Locale Data: ICU uses and supports data from Common Locale Data
    Repository (CLDR) 1.5.0.1, which includes many improvements in
    quality and quantity of data.
  + Rule Based Time Zone: This set of classes provides the ability
    to read and write time zone data in RFC2445 VTIMEZONE format.
    This also provides access Olson timezone transitions.
  + Timezone Formatting: This has changed to give more human
    readable results.
  + Relative Date/Time Formatting: A draft of the relative date/time
    format class has been added. This functionality can be accessed
    through the DateFormat::createDateInstance or DateFormat.getInstance
    factory method. It provides the ability to format localized dates
    in terms of "yesterday", "today" and "tomorrow", instead of a
    specific only date or time.
  + Demonstrations and Tools
  * ICU Data Library Customizer: This new online tool provides an
    easier way customize ICU's data.
  * ICU4J Demonstrations: These will demonstrate some features of
    ICU4J, like calendars, transliteration, and several other
    features.
  + Flexible Date/Time Formatting: A draft of flexible date/time
    format generator has been added. This allows multiple date and
    time format patterns to be generated that are valid for specific
    locales. This funtionality can be accessed through the
    DateTimePatternGenerator API.
  + Time Zones: The default time zone is detected more accurately
    on Unix machines.
  + Additional Calendars
  * @calendar=taiwan: This calendar is a variant of the Gregorian
    calendar used in Taiwan.
  * @calendar=indian: This is the Indian national calendar.
  * @calendar=persian: This is the Persian calendar. It is also
    known as the Jalāli Calendar. It is used in several Arabic
    countries.
  + UnicodeSet
  * The Freezable design pattern is now supported, which can
    improve performance for the contains() and span() methods
    on frozen UnicodeSet objects.
  * A span function was added for iterating through strings.
  * The containsAll(string) and containsNone(string) now support
    set strings, instead of only codepoints.
  + Performance
  * Charset conversion performance has been enhanced. The
    amount of improvement varies depending on the converter
    being used and platform being used.
  * Rule based transliterator construction performance has been
    improved.
- s#%%run_ldconfig#/sbin/ldconfig# in libicu's %%post and %%postun
- add libicu-regex.patch (bnc#354372).
* Thu Feb  7 2008 pmladek@suse.cz
- made RuleBasedBreakIterator::setBreakType method pubclic; it was requested by
  OpenOffice_org >= 2.3.1, see http://bugs.icu-project.org/trac/ticket/5498
* Wed Jul 25 2007 pmladek@suse.cz
- Updated to version 3.6
  * supports Unicode 5.0
  * supports data from Common Locale Data Repository (CLDR) 1.4
  * charset detection framework was added
  * font layout engine has support added for Tibetan, Sinhala and Old Hangul
  * BiDi algorithm was enhanced to be more flexible and efficient
  * new icupkg tool provides an easier way to manage ICU's data library
  * time zone data is modularized to allow easier building and updating of
    the data
  * BreakIterator uses UText for abstract text processing
  * 64-bit indexing is now used to allow access to larger chunks of text
  * added API for read-only locking for security and robustness
  * lots performance improvements
* Mon Feb 13 2006 olh@suse.de
- mark libraries as executable to extract debuginfo
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Aug  3 2005 sbrabec@suse.cz
- Updated to version 3.4.
* Mon Mar 28 2005 gekker@suse.de
- Move icu-config to libicu-devel package (8030).
* Mon Jan 10 2005 sbrabec@suse.cz
- Updated to version 3.2 (#49578).
  Updated by Robert Schiele <rschiele@uni-mannheim.de>.
- Added -fno-strict-aliasing.
* Fri Nov 19 2004 ro@suse.de
- ignore return-code from strip call
* Tue May 25 2004 clahey@suse.de
- Removed --with-data-packaging=files.  Fixes gtk-sharp compilation.
* Mon May 24 2004 clahey@suse.de
- Updated to 2.6.2.
* Wed Mar 31 2004 mfabian@suse.de
- Bugzilla #37029: "strip --strip-debug" static libraries to save
  space on the CDs.
* Fri Jan 23 2004 uli@suse.de
- removed --disable-rpath; it is unnecessary and breaks the
  icu-config script
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Tue Sep 23 2003 mfabian@suse.de
- Bugzilla #31665: "SuSEconfig.icu is not lib64 clean" fixed.
* Mon Aug 18 2003 mfabian@suse.de
- update to 2.6.
* Mon Jun 16 2003 mfabian@suse.de
- fix "directory not owned by any package".
* Fri May 16 2003 mfabian@suse.de
- fix file list, remove CVS directories.
* Wed Sep 11 2002 mfabian@suse.de
- /usr/sbin/gencnval is now in /usr/bin/gencnval.
  Fix SuSEconfig.icu accordingly.
* Fri Aug 16 2002 mfabian@suse.de
- update to 2.2
* Sun Aug 11 2002 mfabian@suse.de
- add Provides: libicu17 to libicu21 subpackage
  (to trigger the selection of the new package during update.)
* Fri Aug  9 2002 mfabian@suse.de
- update to 2.1
* Tue Mar 12 2002 mfabian@suse.de
- use %%{_libdir}
* Tue Mar 12 2002 kukuk@suse.de
- Fix most wrong directories in filelist
* Mon Feb 11 2002 ro@suse.de
- tar option for bz2 is "j"
* Wed Mar  7 2001 mfabian@suse.de
- new package: icu 1.7
- package names as described in PACKAGING
